@@ -2,7 +2,7 @@
 #'
 #' @description In this version only hourly data can be enriched.
 #'
-#' @param opts \code{simOptions} obtain wich \link[antaresRead]{setSimulationPath}
+#' @param opts \code{simOptions} obtain which \link[antaresRead]{setSimulationPath}
 #' @param mcY  \code{character}, "mcInd" or "mcAll".
 #' @param timeStep \code{character}, timeStep
 #' @param addNetLoad  \code{boolean} refer to \link[antaresProcessing]{addNetLoad}
@@ -10,7 +10,6 @@
 #' @param addUpwardMargin \code{boolean} refer to \link[antaresProcessing]{addUpwardMargin}
 #' @param addExportAndImport \code{boolean} refer to \link[antaresProcessing]{addExportAndImport}
 #' @param addLoadFactorLink \code{boolean} refer to \link[antaresProcessing]{addLoadFactorLink}
-#' @param correctBalance \code{boolean} refer to \link[antaresProcessing]{correctBalance}
 #' @param externalDependency \code{boolean} refer to \link[antaresProcessing]{externalDependency}
 #' @param loadFactor \code{boolean} refer to \link[antaresProcessing]{loadFactor}
 #' @param modulation \code{boolean} refer to \link[antaresProcessing]{modulation}
@@ -21,7 +20,7 @@
 #' Should loadFactorAvailable be added to the result of \link[antaresProcessing]{loadFactor}.
 #' @param allProcess \code{boolean} All process in one argument.
 #' @param linkCapacity \code{boolean} should export and import capacities be computed by \link[antaresProcessing]{addExportAndImport}.
-#' @param mustRun \code{boolean} should the production in must run mode substracted to the net load \link[antaresProcessing]{addNetLoad}.
+#' @param mustRun \code{boolean} should the production in must run mode subtracted to the net load \link[antaresProcessing]{addNetLoad}.
 #' Should the must run production be ignored in the computation of the netLoadRamp see \link[antaresProcessing]{netLoadRamp}.
 #' @param evalAreas \code{list}, list of operation to evaluate in areas data
 #' @param evalLinks \code{list}, list of operation to evaluate in links data
@@ -55,7 +54,6 @@
 #'                addUpwardMargin = TRUE,
 #'                addExportAndImport = TRUE,
 #'                addLoadFactorLink = TRUE,
-#'                correctBalance = TRUE,
 #'                externalDependency = TRUE,
 #'                loadFactor = TRUE,
 #'                modulation = TRUE,
@@ -85,7 +83,6 @@ addProcessingH5 <- function(opts = simOptions(),
                             addUpwardMargin = FALSE,
                             addExportAndImport = FALSE,
                             addLoadFactorLink = FALSE,
-                            correctBalance = FALSE,
                             externalDependency = FALSE,
                             loadFactor = FALSE,
                             modulation = FALSE,
@@ -99,269 +96,267 @@ addProcessingH5 <- function(opts = simOptions(),
                             evalAreas = list(),
                             evalLinks = list(),
                             evalClusters = list(),
-                            evalDistricts = list(), nThreads = 1){
+                            evalDistricts = list(), nThreads = 1) {
+  if (!requireNamespace("rhdf5", quietly = TRUE)) {
+    stop("Package 'rhdf5' is required to use this function.", call. = FALSE)
+  } else {
 
-  .setAliasH5()
+    .setAliasH5()
 
-  if(!isH5Opts(opts)){
-    stop("opts not refear to an h5 file")
-  }
-
-  if(correctBalance){
-    try({
-      correctBalance(x = opts)
-    })
-  }
-
-  allData <- allProcess
-  if(allData){
-    addNetLoad <- TRUE
-    addDownwardMargin <- TRUE
-    addUpwardMargin <- TRUE
-    addExportAndImport <- TRUE
-    addLoadFactorLink <- TRUE
-    externalDependency <- TRUE
-    loadFactor <- TRUE
-    modulation <- TRUE
-    netLoadRamp <- TRUE
-    surplus <- TRUE
-    surplusClusters <- TRUE
-  }
-
-  if(netLoadRamp){
-    externalDependency <- TRUE
-  }
-
-
-
-  mcY <- match.arg(mcY)
-
-  if(mcY == "mcAll"){
-    nThreads = 1
-  }
-  allStraitments <- list(
-    addNetLoad = addNetLoad,
-    addDownwardMargin = addDownwardMargin,
-    addUpwardMargin = addUpwardMargin,
-    addExportAndImport = addExportAndImport,
-    addLoadFactorLink = addLoadFactorLink,
-    externalDependency = externalDependency,
-    loadFactor = loadFactor,
-    modulation = modulation,
-    netLoadRamp = netLoadRamp,
-    surplus = surplus,
-    surplusClusters = surplusClusters)
-
-  columnsToAdd <- .getNewColumnsName(allStraitments)
-  writeAreas <- ifelse(is.null(columnsToAdd$areas) & length(evalAreas) == 0, FALSE, TRUE)
-  writeLinks <- ifelse(is.null(columnsToAdd$links) & length(evalLinks) == 0, FALSE, TRUE)
-  writeClusters <- ifelse(is.null(columnsToAdd$clusters) & length(evalClusters) == 0, FALSE, TRUE)
-  writeDistricts <- ifelse(is.null(columnsToAdd$districts) & length(evalDistricts) == 0, FALSE, TRUE)
-
-  select <- .getSelectAlias(allStraitments)
-
-
-  ##Load removeVirtAreas
-  if(allStraitments$surplus == TRUE)
-  {
-    .requireRhdf5_Antares(stopP = TRUE)
-    fid <- rhdf5::H5Fopen(opts$h5path)
-    removeAre <- .loadAttributes(fid, "hourly")
-    rhdf5::H5Fclose(fid)
-    if("virtualNodes" %in% names(removeAre))
-    {
-      removeAre <- unlist(removeAre$virtualNodes)
-      select <- c(select, removeAre)
+    if (!isH5Opts(opts)) {
+      stop("opts not refear to an h5 file")
     }
 
-  }
-
-  columnsToSelects <- unique(unlist(lapply(list(evalAreas,evalLinks,evalClusters,  evalDistricts ), function(Z){
-    lapply(Z, function(X){
-      strsplit(X, "`")
-    })
-  })))
-
-  ##Load first Mcyear
-
-  if(mcY == "mcInd")
-  {
-    mcYear <- opts$mcYears
-    # if(!isTRUE(all.equal(1:length(mcYear), mcYear))){
-    #   mcYear <- 1:length(mcYear)
-    # }
-  }
-  if(mcY == "mcAll")
-  {
-    mcYear <- "mcAll"
-  }
-  # timeStep <- "hourly"
-
-
-  if(mcYear[1] != 'mcAll')
-  {
-    by = nThreads
-    mcYear_L <- vector("list", floor((length(mcYear)-1)/by) + 1 )
-    for(i in 1:length(mcYear))
-    {
-      mcYear_L[[floor((i-1)/by) + 1]] <- c(mcYear_L[[floor((i-1)/by) + 1]], mcYear[i])
-    }
-    mcYear <- mcYear_L
-  }else{
-    mcYear <- list(mcYear)
-  }
-  if(nThreads > 1){
-
-    if(!requireNamespace("parallel")) stop("Error loading 'parallel' package.")
-
-    cl <- parallel::makeCluster(length(mcYear[[1]]))
-    Parallel = TRUE
-
-    parallel::clusterExport(cl, c("opts"), envir = environment())
-    parallel::clusterEvalQ(cl = cl, {
-      require(antaresProcessing)
-      .setAliasH5()
-      opts <- setSimulationPath(opts$h5path)
-    })
-
-  }else{
-    Parallel = FALSE
-  }
-
-  outToWrite <- lapply(1:length(mcYear), function(x){
-    X <- mcYear[[x]]
-    if(X[1] == "mcAll"){
-      X <- NULL
+    allData <- allProcess
+    if (allData) {
+      addNetLoad <- TRUE
+      addDownwardMargin <- TRUE
+      addUpwardMargin <- TRUE
+      addExportAndImport <- TRUE
+      addLoadFactorLink <- TRUE
+      externalDependency <- TRUE
+      loadFactor <- TRUE
+      modulation <- TRUE
+      netLoadRamp <- TRUE
+      surplus <- TRUE
+      surplusClusters <- TRUE
     }
 
-    if(!Parallel)
-    {
-      myOut <- .readDataEndAddColumn(opts, select = select, mcYears = X, timeStep = timeStep,
-                                     evalAreas = evalAreas, evalLinks = evalLinks,
-                                     evalClusters = evalClusters, evalDistricts = evalDistricts,
-                                     columnsToSelects = columnsToSelects, allStraitments = allStraitments,
-                                     writeAreas = writeAreas,
-                                     writeLinks = writeLinks,
-                                     writeClusters = writeClusters,
-                                     writeDistricts = writeDistricts,
-                                     columnsToAdd = columnsToAdd,
-                                     linkCapacity = linkCapacity, mustRun = mustRun,
-                                     thermalAvailabilities = thermalAvailabilities)
-    }else{
-      parallel::clusterExport(cl, c("opts", "select", "X",  "timeStep",
-                                    "evalAreas", "evalLinks",
-                                    "evalClusters", "evalDistricts",
-                                    "columnsToSelects","allStraitments",
-                                    "writeAreas",
-                                    "writeLinks",
-                                    "writeClusters",
-                                    "writeDistricts",
-                                    "columnsToAdd",
-                                    "linkCapacity",
-                                    "mustRun",
-                                    "thermalAvailabilities"), envir = environment())
-      myOut <- parallel::parSapply(cl, X, function(Y){
-        .readDataEndAddColumn(opts, select = select, mcYears = Y, timeStep = timeStep,
-                              evalAreas = evalAreas, evalLinks = evalLinks,
-                              evalClusters = evalClusters, evalDistricts = evalDistricts,
-                              columnsToSelects = columnsToSelects, allStraitments = allStraitments,
-                              writeAreas = writeAreas,
-                              writeLinks = writeLinks,
-                              writeClusters = writeClusters,
-                              writeDistricts = writeDistricts,
-                              columnsToAdd = columnsToAdd,
-                              linkCapacity = linkCapacity, mustRun = mustRun,
-                              thermalAvailabilities = thermalAvailabilities)
+    if (netLoadRamp) {
+      externalDependency <- TRUE
+    }
+
+
+
+    mcY <- match.arg(mcY)
+
+    if (mcY == "mcAll") {
+      nThreads = 1
+    }
+    allStraitments <- list(
+      addNetLoad = addNetLoad,
+      addDownwardMargin = addDownwardMargin,
+      addUpwardMargin = addUpwardMargin,
+      addExportAndImport = addExportAndImport,
+      addLoadFactorLink = addLoadFactorLink,
+      externalDependency = externalDependency,
+      loadFactor = loadFactor,
+      modulation = modulation,
+      netLoadRamp = netLoadRamp,
+      surplus = surplus,
+      surplusClusters = surplusClusters)
+
+    columnsToAdd <- .getNewColumnsName(allStraitments)
+    writeAreas <- ifelse(is.null(columnsToAdd$areas) & length(evalAreas) == 0, FALSE, TRUE)
+    writeLinks <- ifelse(is.null(columnsToAdd$links) & length(evalLinks) == 0, FALSE, TRUE)
+    writeClusters <- ifelse(is.null(columnsToAdd$clusters) & length(evalClusters) == 0, FALSE, TRUE)
+    writeDistricts <- ifelse(is.null(columnsToAdd$districts) & length(evalDistricts) == 0, FALSE, TRUE)
+
+    select <- .getSelectAlias(allStraitments)
+
+
+    ##Load removeVirtAreas
+    if(allStraitments$surplus == TRUE) {
+      .requireRhdf5_Antares(stopP = TRUE)
+      fid <- rhdf5::H5Fopen(opts$h5path)
+      removeAre <- .loadAttributes(fid, "hourly")
+      rhdf5::H5Fclose(fid)
+      if("virtualNodes" %in% names(removeAre))
+      {
+        removeAre <- unlist(removeAre$virtualNodes)
+        select <- c(select, removeAre)
+      }
+
+    }
+
+    columnsToSelects <- unique(unlist(lapply(list(evalAreas,evalLinks,evalClusters,  evalDistricts ), function(Z){
+      lapply(Z, function(X){
+        strsplit(X, "`")
+      })
+    })))
+
+    ##Load first Mcyear
+
+    if(mcY == "mcInd") {
+      mcYear <- opts$mcYears
+      # if(!isTRUE(all.equal(1:length(mcYear), mcYear))){
+      #   mcYear <- 1:length(mcYear)
+      # }
+    }
+    if(mcY == "mcAll") {
+      mcYear <- "mcAll"
+    }
+    # timeStep <- "hourly"
+
+
+    if (mcYear[1] != 'mcAll') {
+      by = nThreads
+      mcYear_L <- vector("list", floor((length(mcYear)-1)/by) + 1 )
+      for(i in 1:length(mcYear)) {
+        mcYear_L[[floor((i-1)/by) + 1]] <- c(mcYear_L[[floor((i-1)/by) + 1]], mcYear[i])
+      }
+      mcYear <- mcYear_L
+    } else {
+      mcYear <- list(mcYear)
+    }
+    if (nThreads > 1) {
+
+      if (!requireNamespace("parallel")) stop("Error loading 'parallel' package.")
+
+      cl <- parallel::makeCluster(length(mcYear[[1]]))
+      Parallel = TRUE
+
+      parallel::clusterExport(cl, c("opts"), envir = environment())
+      parallel::clusterEvalQ(cl = cl, {
+        require(antaresProcessing)
+        .setAliasH5()
+        opts <- setSimulationPath(opts$h5path)
+      })
+
+    } else {
+      Parallel = FALSE
+    }
+
+    outToWrite <- lapply(1:length(mcYear), function(x) {
+      X <- mcYear[[x]]
+      if (X[1] == "mcAll") {
+        X <- NULL
+      }
+
+      if(!Parallel) {
+        myOut <- .readDataEndAddColumn(opts, select = select, mcYears = X, timeStep = timeStep,
+                                       evalAreas = evalAreas, evalLinks = evalLinks,
+                                       evalClusters = evalClusters, evalDistricts = evalDistricts,
+                                       columnsToSelects = columnsToSelects, allStraitments = allStraitments,
+                                       writeAreas = writeAreas,
+                                       writeLinks = writeLinks,
+                                       writeClusters = writeClusters,
+                                       writeDistricts = writeDistricts,
+                                       columnsToAdd = columnsToAdd,
+                                       linkCapacity = linkCapacity, mustRun = mustRun,
+                                       thermalAvailabilities = thermalAvailabilities)
+      } else {
+        parallel::clusterExport(cl, c("opts", "select", "X",  "timeStep",
+                                      "evalAreas", "evalLinks",
+                                      "evalClusters", "evalDistricts",
+                                      "columnsToSelects","allStraitments",
+                                      "writeAreas",
+                                      "writeLinks",
+                                      "writeClusters",
+                                      "writeDistricts",
+                                      "columnsToAdd",
+                                      "linkCapacity",
+                                      "mustRun",
+                                      "thermalAvailabilities"), envir = environment())
+        myOut <- parallel::parSapply(cl, X, function(Y){
+          .readDataEndAddColumn(opts, select = select, mcYears = Y, timeStep = timeStep,
+                                evalAreas = evalAreas, evalLinks = evalLinks,
+                                evalClusters = evalClusters, evalDistricts = evalDistricts,
+                                columnsToSelects = columnsToSelects, allStraitments = allStraitments,
+                                writeAreas = writeAreas,
+                                writeLinks = writeLinks,
+                                writeClusters = writeClusters,
+                                writeDistricts = writeDistricts,
+                                columnsToAdd = columnsToAdd,
+                                linkCapacity = linkCapacity, mustRun = mustRun,
+                                thermalAvailabilities = thermalAvailabilities)
+        }, simplify = FALSE)
+
+
+        namS <- names(myOut[[1]])
+        myOut <- sapply(1:length(myOut[[1]]), function(V){
+          rbindlist(sapply(1:length(myOut), function(W){
+            myOut[[W]][[V]]
+          }, simplify = FALSE))
+        }, simplify = FALSE)
+        names(myOut) <- namS
+
+      }
+
+      outList <- names(myOut)
+      myOut$areas
+      outToWrite <- sapply(outList, function(HH){
+        tp <- as.matrix(myOut[[HH]])
+        tp[is.na(tp)] <- -9999
+        tp
       }, simplify = FALSE)
 
 
-      namS <- names(myOut[[1]])
-      myOut <- sapply(1:length(myOut[[1]]), function(V){
-        rbindlist(sapply(1:length(myOut), function(W){
-          myOut[[W]][[V]]
-        }, simplify = FALSE))
-      }, simplify = FALSE)
-      names(myOut) <- namS
-
-    }
-
-    outList <- names(myOut)
-    myOut$areas
-    outToWrite <- sapply(outList, function(HH){
-      tp <- as.matrix(myOut[[HH]])
-      tp[is.na(tp)] <- -9999
-      tp
-    }, simplify = FALSE)
+      if (is.null(X)) {
+        writeStruct <- TRUE
+      } else{
+        writeStruct <- unique(X == mcYear[[1]])
+      }
 
 
-    if(is.null(X)){
-      writeStruct <- TRUE
-    }else{
-      writeStruct <- unique(X == mcYear[[1]])
-    }
+      writeAreas <- "areas" %in% names(outToWrite)
+      writeLinks <- "links" %in% names(outToWrite)
+      writeClusters <- "clusters" %in% names(outToWrite)
+      writeDistricts <- "districts" %in% names(outToWrite)
 
 
-    writeAreas <- "areas" %in% names(outToWrite)
-    writeLinks <- "links" %in% names(outToWrite)
-    writeClusters <- "clusters" %in% names(outToWrite)
-    writeDistricts <- "districts" %in% names(outToWrite)
-
-
-    .writeAllTables(timeStep = timeStep,
-                    mcY = mcY,
-                    path = opts$h5path,
-                    outToWrite = outToWrite ,
-                    areas = writeAreas,
-                    links = writeLinks,
-                    clusters = writeClusters,
-                    districts = writeDistricts,
-                    mcYear = x, writeStruct = writeStruct)
+      .writeAllTables(timeStep = timeStep,
+                      mcY = mcY,
+                      path = opts$h5path,
+                      outToWrite = outToWrite ,
+                      areas = writeAreas,
+                      links = writeLinks,
+                      clusters = writeClusters,
+                      districts = writeDistricts,
+                      mcYear = x, writeStruct = writeStruct)
 
 
 
-  })
-  if(Parallel) parallel::stopCluster(cl)
+    })
+    if (Parallel) parallel::stopCluster(cl)
 
 
-  ##Add control on straitments to define all this objects
+    ##Add control on straitments to define all these objects
 
-  ##IfverWiteAreas
+    ##IfverWiteAreas
 
+  }
 }
 
 .writeAllTables <- function(timeStep, mcY, path, outToWrite,
                             areas, links, clusters, districts,
                             mcYear = NULL, writeStruct = FALSE){
-  .requireRhdf5_Antares(stopP = TRUE)
-  fid <- rhdf5::H5Fopen(path)
-  sapply(c("areas", "links", "clusters", "districts"), function(X){
-    if(get(X)){
-      fid <- rhdf5::H5Fopen(path)
-      Y <- eval(X)
-      GP <- paste0(timeStep, "/", Y, "/", mcY)
-      .writeNewColumns(fid = fid,
-                       newdata = outToWrite[[Y]],
-                       GP = GP, mcYear = mcYear,
-                       writeStruct = writeStruct)
-    }
-
-  })
+  if (!requireNamespace("rhdf5", quietly = TRUE)) {
+    stop("Package 'rhdf5' is required to use this function.", call. = FALSE)
+  } else {
+    .requireRhdf5_Antares(stopP = TRUE)
+    fid <- rhdf5::H5Fopen(path)
+    sapply(c("areas", "links", "clusters", "districts"), function(X){
+      if(get(X)){
+        fid <- rhdf5::H5Fopen(path)
+        Y <- eval(X)
+        GP <- paste0(timeStep, "/", Y, "/", mcY)
+        .writeNewColumns(fid = fid,
+                         newdata = outToWrite[[Y]],
+                         GP = GP, mcYear = mcYear,
+                         writeStruct = writeStruct)
+      }
 
+    })
+  }
 }
 
 
-.getDim <- function(fid, GP, type = "size")
-{
-  .requireRhdf5_Antares(stopP = TRUE)
-  did <- rhdf5::H5Dopen(fid, GP)
-  rhdf5::H5Dget_space(did)
-  res <- rhdf5::H5Dget_space(did)
-  rhdf5::H5Dclose(did)
-  dim <- rhdf5::H5Sget_simple_extent_dims(res)[[type]]
-  dim
+.getDim <- function(fid, GP, type = "size") {
+  if (!requireNamespace("rhdf5", quietly = TRUE)) {
+    stop("Package 'rhdf5' is required to use this function.", call. = FALSE)
+  } else {
+    .requireRhdf5_Antares(stopP = TRUE)
+    did <- rhdf5::H5Dopen(fid, GP)
+    rhdf5::H5Dget_space(did)
+    res <- rhdf5::H5Dget_space(did)
+    rhdf5::H5Dclose(did)
+    dim <- rhdf5::H5Sget_simple_extent_dims(res)[[type]]
+    dim
+  }
 }
 
-.getIndexToWrite <- function(dim, nbVarToWrite, mcYear = NULL){
+.getIndexToWrite <- function(dim, nbVarToWrite, mcYear = NULL) {
   d4 <- if(is.null(mcYear)){1:dim[4]}else{mcYear}
   list(1:dim[1], (dim[2] + 1) : (dim[2] + nbVarToWrite), 1:dim[3], d4)
 }
@@ -377,7 +372,7 @@ addProcessingH5 <- function(opts = simOptions(),
                                   writeDistricts, columnsToAdd,
                                   linkCapacity,
                                   mustRun,
-                                  thermalAvailabilities){
+                                  thermalAvailabilities) {
 
   if(writeAreas){
     ar <- "all"
@@ -404,7 +399,7 @@ addProcessingH5 <- function(opts = simOptions(),
                      links = ln,
                      clusters = clu,
                      districts = dr,
-                     opts = opts, select = c(select, columnsToSelects),
+                     opts = opts, select = c(select,columnsToSelects),
                      mcYears = mcYears, timeStep = timeStep)
 
   res <- as.antaresDataList(res)
@@ -492,94 +487,96 @@ addProcessingH5 <- function(opts = simOptions(),
 }
 
 
-.writeNewColumns <- function(fid, newdata, GP, mcYear = NULL, writeStruct = FALSE)
-{
+.writeNewColumns <- function(fid, newdata, GP, mcYear = NULL, writeStruct = FALSE) {
 
-  .requireRhdf5_Antares(stopP = TRUE)
+  if (!requireNamespace("rhdf5", quietly = TRUE)) {
+    stop("Package 'rhdf5' is required to use this function.", call. = FALSE)
+  } else {
+    .requireRhdf5_Antares(stopP = TRUE)
+
+    nbVarToWrite <- ncol(newdata)
+    namesVariable <- colnames(newdata)
+    datatype <- paste0(GP, "/data")
+    if(writeStruct)
+    {
+      oldStruct <-  paste0(GP, "/structure/reCalcVar")
+      did <- rhdf5::H5Dopen(fid, oldStruct)
+      structVarAdd <- rhdf5::H5Dread(did)
+      rhdf5::H5Dclose(did)
+      if(sum(namesVariable %in% structVarAdd) > 0 )
+      {
+        warning("Somes columns already exists in h5 file, they will be overwrite.")
+        namesVariable <- namesVariable[!namesVariable %in% structVarAdd]
+
+      }
+      if(length(namesVariable) > 0){
+        structVarAdd[which(structVarAdd == "")][1:length(namesVariable)] <- namesVariable
+
+        #h5write(structVarAdd, path, oldStruct)
+        rhdf5::h5writeDataset.array(obj = structVarAdd,  fid, oldStruct)
+
+
+        # if(grepl("areas", GP))
+        # {
+        #   attributes <- .loadAttributes(fid, "hourly")
+        #   attributes$opts$variables$areas <- unique(c(attributes$opts$variables$areas, namesVariable))
+        #   .writeAttributes(path = NULL, timeStep =  "hourly", fid = fid, attributes = attributes)
+        #
+        # }
+        #
+        # if(grepl("links", GP))
+        # {
+        #   attributes <- .loadAttributes(fid, "hourly")
+        #   attributes$opts$variables$links <- unique(c(attributes$opts$variables$links, namesVariable))
+        #   .writeAttributes(path = NULL, timeStep =  "hourly", fid = fid, attributes = attributes)
+        #
+        # }
+
+      }
+    }
 
-  nbVarToWrite <- ncol(newdata)
-  namesVariable <- colnames(newdata)
-  datatype <- paste0(GP, "/data")
-  if(writeStruct)
-  {
     oldStruct <-  paste0(GP, "/structure/reCalcVar")
     did <- rhdf5::H5Dopen(fid, oldStruct)
-    structVarAdd <- rhdf5::H5Dread(did)
-    rhdf5::H5Dclose(did)
-    if(sum(namesVariable %in% structVarAdd) > 0 )
+    allVarAdd <- rhdf5::H5Dread(did )
+
+
+    oldStruct <-  paste0(GP, "/structure/variable")
+    did <- rhdf5::H5Dopen(fid, oldStruct)
+    allnorm <- rhdf5::H5Dread(did )
+    allVarAdd <- c(allnorm, allVarAdd)
+    indexVar <- sapply(colnames(newdata), function(X){
+      which(allVarAdd == X)
+    })
+
+
+    actualDim <- .getDim(fid, datatype)
+    indexToWrite <- .getIndexToWrite(actualDim, nbVarToWrite, mcYear)
+    dimtowrite <- unlist(lapply(indexToWrite, length))
+    indexToWrite[[2]] <- unlist(indexVar)
+
+    arrayToWrite <- array(newdata, dimtowrite[c(1,3,4,2)])
+    # dim(arrayToWrite)
+    arrayToWrite <- aperm(arrayToWrite, c(1,4,2,3))
+
+    newDim <- actualDim
+    newDim[2] <- newDim[2] + dimtowrite[2]
+    if(writeStruct && length(namesVariable)>0)
     {
-      warning("Somes columns already exists in h5 file, they will be overwrite.")
-      namesVariable <- namesVariable[!namesVariable %in% structVarAdd]
-
-    }
-    if(length(namesVariable) > 0){
-      structVarAdd[which(structVarAdd == "")][1:length(namesVariable)] <- namesVariable
-
-      #h5write(structVarAdd, path, oldStruct)
-      rhdf5::h5writeDataset.array(obj = structVarAdd,  fid, oldStruct)
-
-
-      # if(grepl("areas", GP))
-      # {
-      #   attributes <- .loadAttributes(fid, "hourly")
-      #   attributes$opts$variables$areas <- unique(c(attributes$opts$variables$areas, namesVariable))
-      #   .writeAttributes(path = NULL, timeStep =  "hourly", fid = fid, attributes = attributes)
-      #
-      # }
-      #
-      # if(grepl("links", GP))
-      # {
-      #   attributes <- .loadAttributes(fid, "hourly")
-      #   attributes$opts$variables$links <- unique(c(attributes$opts$variables$links, namesVariable))
-      #   .writeAttributes(path = NULL, timeStep =  "hourly", fid = fid, attributes = attributes)
-      #
-      # }
-
+      rhdf5::h5set_extent(fid, datatype, c(newDim))
     }
+    rhdf5::h5writeDataset.array(obj = arrayToWrite, fid, datatype, index = indexToWrite)
+    rhdf5::H5close()
   }
-
-  oldStruct <-  paste0(GP, "/structure/reCalcVar")
-  did <- rhdf5::H5Dopen(fid, oldStruct)
-  allVarAdd <- rhdf5::H5Dread(did )
-
-
-  oldStruct <-  paste0(GP, "/structure/variable")
-  did <- rhdf5::H5Dopen(fid, oldStruct)
-  allnorm <- rhdf5::H5Dread(did )
-  allVarAdd <- c(allnorm, allVarAdd)
-  indexVar <- sapply(colnames(newdata), function(X){
-    which(allVarAdd == X)
-  })
-
-
-  actualDim <- .getDim(fid, datatype)
-  indexToWrite <- .getIndexToWrite(actualDim, nbVarToWrite, mcYear)
-  dimtowrite <- unlist(lapply(indexToWrite, length))
-  indexToWrite[[2]] <- unlist(indexVar)
-
-  arrayToWrite <- array(newdata, dimtowrite[c(1,3,4,2)])
-  # dim(arrayToWrite)
-  arrayToWrite <- aperm(arrayToWrite, c(1,4,2,3))
-
-  newDim <- actualDim
-  newDim[2] <- newDim[2] + dimtowrite[2]
-  if(writeStruct && length(namesVariable)>0)
-  {
-    rhdf5::h5set_extent(fid, datatype, c(newDim))
-  }
-  rhdf5::h5writeDataset.array(obj = arrayToWrite, fid, datatype, index = indexToWrite)
-  rhdf5::H5close()
 }
 
 
-.getNewColumnsName <- function(allStraitments)
-{
+.getNewColumnsName <- function(allStraitments) {
   areas <- NULL
   links <- NULL
   clusters <- NULL
   districts <- NULL
-  for(X in pkgEnv$processDispo$fctname){
-    if(get(paste0("allStraitments"))[[X]]){
+  for (X in pkgEnv$processDispo$fctname) {
+    if (get(paste0("allStraitments"))[[X]]) {
       areas <- c(areas, pkgEnv$process[[X]]$areas)
       links <- c(links, pkgEnv$process[[X]]$links)
       clusters <- c(clusters, pkgEnv$process[[X]]$clusters)
@@ -593,13 +590,13 @@ addProcessingH5 <- function(opts = simOptions(),
        districts = districts)
 }
 
-.getSelectAlias <- function(allStraitments){
+.getSelectAlias <- function(allStraitments) {
   as.character(pkgEnv$processDispo[pkgEnv$processDispo$fctname%in%
                                      names(which(unlist(allStraitments))),]$trtName)
 }
 
 
-.calcNewColumns <- function(res, allStraitments, timeStep, linkCapacity, mustRun, thermalAvailabilities, opts){
+.calcNewColumns <- function(res, allStraitments, timeStep, linkCapacity, mustRun, thermalAvailabilities, opts) {
 
   oldw <- getOption("warn")
   options(warn = -1)
@@ -764,14 +761,13 @@ addProcessingH5 <- function(opts = simOptions(),
       res$clusters <- merge(res$clusters, surplusClusters, by = idC)
     })
   }
-
   options(warn = oldw)
   res
 }
 
 #'@export
 #'@noRd
-.setAliasH5 <- function(){
+.setAliasH5 <- function() {
   sapply(names(pkgEnv$process), function(X){
     tpAlias <- pkgEnv$process[[X]]
     X <- paste0("Out_", X)
@@ -784,27 +780,30 @@ addProcessingH5 <- function(opts = simOptions(),
 
 
 
-.loadAttributes <- function(fid, timeStep){
+.loadAttributes <- function(fid, timeStep) {
 
-  .requireRhdf5_Antares(stopP = TRUE)
+  if (!requireNamespace("rhdf5", quietly = TRUE)) {
+    stop("Package 'rhdf5' is required to use this function.", call. = FALSE)
+  } else {
+    .requireRhdf5_Antares(stopP = TRUE)
 
-  if(rhdf5::H5Lexists(fid, paste0(timeStep, "/attrib")))
-  {
+    if (rhdf5::H5Lexists(fid, paste0(timeStep, "/attrib"))) {
 
-    did <- rhdf5::H5Dopen(fid, paste0(timeStep, "/attrib"))
-    attrib <- unserialize(charToRaw(rhdf5::H5Dread(did)))
-    rhdf5::H5Dclose(did)
+      did <- rhdf5::H5Dopen(fid, paste0(timeStep, "/attrib"))
+      attrib <- unserialize(charToRaw(rhdf5::H5Dread(did)))
+      rhdf5::H5Dclose(did)
 
-    if(!is.null(attrib$opts$linksDef)){
-      attrib$opts$linksDef <- data.table(attrib$opts$linksDef)
+      if (!is.null(attrib$opts$linksDef)) {
+        attrib$opts$linksDef <- data.table(attrib$opts$linksDef)
+      }
+      if (!is.null(attrib$opts$districtsDef)) {
+        attrib$opts$districtsDef <- data.table(attrib$opts$districtsDef)
+      }
+    } else {
+      attrib <- NULL
     }
-    if(!is.null(attrib$opts$districtsDef)){
-      attrib$opts$districtsDef <- data.table(attrib$opts$districtsDef)
-    }
-  }else{
-    attrib <- NULL
+    attrib
   }
-  attrib
 }
 # library(antaresProcessing)
 # library(data.table)
