@@ -1,7 +1,23 @@
 context("h5 : addProcessingH5")
 
+#write data
+skipFunctionH5<-function(){
+  skip_if(is.null(h5file), "h5file is null")
+  if(!is.null(h5file)){
+    skip_if(!check_if_h5_is_in_tmp(h5file), "h5file is not in temp folder")
+  }
+  skip_if_not(.requireRhdf5_Antares(stopP = FALSE),
+              "please install a correct rhdf5 version")
+
+  #I dont why but according to CRAN Team antaresProcessing try to write in the user library
+  # but there are checks to verify that h5 file is in tmp folder
+  #to comment in the futur
+  # skip_on_cran()
+}
+
 test_that("h5 : processing, write results", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   .setAliasH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",
@@ -10,7 +26,6 @@ test_that("h5 : processing, write results", {
                                     addUpwardMargin = TRUE,
                                     addExportAndImport = TRUE,
                                     addLoadFactorLink = TRUE,
-                                    correctBalance = TRUE,
                                     externalDependency = TRUE,
                                     loadFactor = TRUE,
                                     modulation = TRUE,
@@ -27,7 +42,8 @@ test_that("h5 : processing, write results", {
 })
 
 test_that("h5 : processing, write results mcAll", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   .setAliasH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcAll",
@@ -36,7 +52,6 @@ test_that("h5 : processing, write results mcAll", {
                                     addExportAndImport = TRUE,
                                     addLoadFactorLink = TRUE,
                                     externalDependency = TRUE,
-                                    correctBalance = TRUE,
                                     loadFactor = TRUE,
                                     modulation = TRUE,
                                     netLoadRamp = TRUE,
@@ -53,7 +68,8 @@ test_that("h5 : processing, write results mcAll", {
 })
 
 test_that("h5 : all data", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",
                                     allProcess = TRUE)})
@@ -69,7 +85,8 @@ test_that("h5 : all data", {
 
 #read data and compare
 test_that("h5 : processing calc by user", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   calcData <- readAntares(areas = "all", mcYears = "all",
                           select = c("H. STOR" , "MISC. DTG",
@@ -83,7 +100,8 @@ test_that("h5 : processing calc by user", {
 })
 
 test_that("h5 : processing calc by straitements", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   UpwardMargin_out <- readAntares(areas = "all", mcYears = "all",
                                   select = "Out_addUpwardMargin", showProgress = FALSE)
 
@@ -99,7 +117,8 @@ test_that("h5 : processing calc by straitements", {
 })
 
 test_that("h5 : processing calc links clusters discticcts", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",
                                     evalLinks = list(totalLink= "`FLOW LIN.` + 10000 "),
@@ -117,7 +136,8 @@ test_that("h5 : processing calc links clusters discticcts", {
 })
 
 test_that("h5 : processing Out_addNetLoad", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",addNetLoad =  TRUE)})
   re <- readAntares(opts = optsH5, areas = "all", districts = "all",
@@ -128,7 +148,8 @@ test_that("h5 : processing Out_addNetLoad", {
 })
 
 test_that("h5 : processing Out_addDownwardMargin", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",addDownwardMargin =  TRUE)})
   re <- readAntares(opts = optsH5, areas = "all", districts = "all",
@@ -141,7 +162,8 @@ test_that("h5 : processing Out_addDownwardMargin", {
 })
 
 test_that("h5 : processing Out_addUpwardMargin", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",addUpwardMargin = TRUE)})
   re <- readAntares(opts = optsH5, areas = "all", districts = "all",
@@ -154,7 +176,8 @@ test_that("h5 : processing Out_addUpwardMargin", {
 })
 
 test_that("h5 : processing Out_addExportAndImport", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",addExportAndImport = TRUE)})
   re <- readAntares(opts = optsH5, areas = "all", districts = "all",
@@ -167,7 +190,8 @@ test_that("h5 : processing Out_addExportAndImport", {
 })
 
 test_that("h5 : processing Out_addLoadFactorLink", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",addLoadFactorLink = TRUE)})
   re <- readAntares(opts = optsH5, links = "all",clusters = "all",
@@ -177,7 +201,8 @@ test_that("h5 : processing Out_addLoadFactorLink", {
 })
 
 test_that("h5 : processing Out_externalDependency", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",externalDependency = TRUE)})
   re <- readAntares(opts = optsH5, areas = "all", districts = "all",
@@ -197,7 +222,8 @@ test_that("h5 : processing Out_externalDependency", {
 })
 
 test_that("h5 : processing Out_loadFactor", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",loadFactor = TRUE)})
   re <- readAntares(opts = optsH5, clusters = "all",
@@ -209,7 +235,8 @@ test_that("h5 : processing Out_loadFactor", {
 })
 
 test_that("h5 : processing Out_modulation", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd", modulation = TRUE)})
 
@@ -222,7 +249,8 @@ test_that("h5 : processing Out_modulation", {
 })
 
 test_that("h5 : processing netLoadRamp", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",netLoadRamp = TRUE)})
 
@@ -239,7 +267,8 @@ test_that("h5 : processing netLoadRamp", {
 })
 
 test_that("h5 : processing surplus", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",surplus  = TRUE)})
 
@@ -262,7 +291,8 @@ test_that("h5 : processing surplus", {
 })
 
 test_that("h5 : Out_surplusClusters", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings({addProcessingH5(opts = optsH5,  mcY = "mcInd",surplusClusters =  TRUE)})
 
@@ -278,7 +308,8 @@ test_that("h5 : Out_surplusClusters", {
 })
 
 test_that("No h5 opts", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   optsH5$h5path <- NULL
   optsH5$h5 <- NULL
@@ -287,14 +318,16 @@ test_that("No h5 opts", {
 })
 
 test_that("Write boolean", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   suppressWarnings(addProcessingH5(optsH5, evalAreas = list(toto = "TRUE")))
   expect_false(is.null(readAntares(mcYears = 1, select = "toto", showProgress = FALSE)$toto))
 })
 
 test_that("Write character", {
-  .skipFunctionH5(h5file)
+  skip_according_to_options()
+  skipFunctionH5()
   optsH5 <- setSimulationPath(h5file)
   expect_error(addProcessingH5(optsH5, evalAreas = list(toto = "'GGG'")))
 })
